Crate xspf

source ·
low-level library for the XSPF format based off of https://xspf.org/spec warning: do not use this library to validate XSPF files, only to parse valid files, or files that can be reasonably assumed to be valid. this library may accept some invalid documents as valid. this library follows the pardigm of “be lax with what you accept but strict with what you output”.

Re-exports

Modules